MY_GENERAL=string.format('/Users/mariovanhoucke/Documenten van Mario/Lua Scripts/Problem with Simulation P2 Engine Windows/')

dofile(MY_GENERAL..'subprocedure_create_objects.lua')

function main()
	
	create_project_object()
	create_schedule_object()
	create_tracking_object()
	create_reader_object()
	create_simulator_object()
	
	output_file = string.format(MY_GENERAL..'resultaat_2parallel.txt')
	file=io.open(output_file,"w")
	file:write("\nPeriods\tA1\tA2")

	-- Parameters for simulation
	local nr_sim=100 --put this high! 10000 e.g.
	
	-- Parameters for normal distribution
	local breakpoints=100
	local sigmapct=0.2
	
	MyReader:read_patterson_file(MY_GENERAL..'2parallel.rcp')
	
	MySimulator:reset_simulation_object(MySchedule)
	MySimulator:create_monte_carlo_object()

	for act=1,MySchedule:get_number_of_activities() do
--		simulate_uniform_distribution(act,1000,3000)
		simulate_normal_distribution(act,sigmapct,breakpoints)
	end
	
	time_unit=100
	MySimulator:set_periodic_time_unit(time_unit)

	io.write("\nNumber of simulations: ",nr_sim)
	MySimulator:set_callback("sim_callback")
	MySimulator:run_simulation(nr_sim,11,1,0,0,0,0)
		
	delete_tracking_object()
	delete_simulator_object()
	delete_schedule_object()
	delete_project_object()
	delete_reader_object()
	release_all_memory()
	
	file:flush()
	file:close()
end

function sim_callback(p1, p2)

	MyTracking:reset_tracking_object()
	MySimulator:write_output_to_tracking_list(MyTracking)

	nrperiods=MyTracking:get_number_of_tracking_periods()

	file:write("\n", nrperiods)

	for act=1,MySchedule:get_number_of_activities() do
		realdur=MyTracking:get_actual_duration(act,nrperiods)
		file:write(string.format('\t%d',realdur))
	end

	return 0
end

function simulate_uniform_distribution(act,left,right)

	-- Simulate Uniform Distribution from interval [left,right] for activity "act"
	MySimulator:set_number_advanced_distributions(act,4)
		
	MySimulator:set_advanced_distributions(act,1,left-1,0)
	MySimulator:set_advanced_distributions(act,2,left,100)
	MySimulator:set_advanced_distributions(act,3,right,100)
	MySimulator:set_advanced_distributions(act,4,right+1,0)
end 

function simulate_normal_distribution(act,sigmapct,breakpoints)

	--[[ Simulate Normal Distribution for activity "act" with
		 with Average = Planned activity duration (pd)
		      StDev = sigmapct * pd (e.g. sigmapct = 0.2)
		 and breakpoints = parameter to control the number of input values for the "set_advanced_distributions"
		 				 = breakpoints * (maximum - minimum)
	  ]]--
	  
	local pd=MySchedule:get_duration(act) 
	local sigma=sigmapct*pd 
	local minimum=0
	local maximum=2*pd

	MySimulator:set_number_advanced_distributions(act,breakpoints*(maximum-minimum))
	io.write("\nNumber of breakpoint for the normal distribution: ",breakpoints*(maximum-minimum))
	for pnt=1,breakpoints*(maximum-minimum) do
		local x=minimum+(pnt-1)/breakpoints
		local norm = (1/(math.sqrt(2*math.pi)*sigma))*math.exp(-(math.pow(x-pd, 2 )/(2*math.pow(sigma, 2))))
		--local norm = (1/(math.sqrt(2*math.pi)*sigma*x))*math.exp(-(math.pow(math.log(x)-pd, 2 )/(2*math.pow(sigma, 2))))
		io.write("\nPnt: "..pnt.."\tX: "..x.."\tNorm: "..norm)
		MySimulator:set_advanced_distributions(act,pnt,x,norm)
	end
end

main()