--[[
	Target: In this example script, it is shown how the network topology of the project example 
			published in the book "Measuring Time - Improving Project Performance using 
			Earned Value Management" (Vanhoucke, page 60) can be calculated using P2 Engine. 
	More information: www.p2engine.com
	Start with: main_procedure_chapter4_part1
	Uses the following subprocedure(s): "subprocedure_create_objects" and "subprocedure_read_files"
	Classes: P2Project, P2Schedule and P2Generator
	Last update: August 27, 2012
--]]

-- Define your path where you unzip your downloaded file from www.p2engine.com (MUST BE CHANGED BY THE USER!!)
MY_PATH=string.format('/Users/mariovanhoucke/Documenten van Mario/Lua Scripts/tutorial/')

-- Other paths are defined automatically (no need to change these paths!)
MY_SCRIPTS=MY_PATH..'MeasuringTimeExamples/'
MY_GENERAL=MY_PATH..'general/'
dofile(MY_GENERAL..'subprocedure_read_files.lua')
dofile(MY_GENERAL..'subprocedure_create_objects.lua')

function main_procedure_chapter4_part1()
	-- Create the three objects
	create_project_object()
	create_schedule_object()

	-- Read the project network of chapter 2 from a file 
	read_a_patterson_file(MY_SCRIPTS..'project_example_measuring_time_figure1_7.rcp')

	-- Calculate the network topology
	calculate_network_topology()

	delete_schedule_object()
	delete_project_object()
	release_all_memory()
end

function calculate_network_topology()
	io.write('\n\nNetwork topology of the network')
	create_generator_object()
	SP,AD,LA,TF=MyGenerator:calculate_topological_structure()
	io.write("\nSerial/parallel indicator (SP)       = ",string.format("%2.2f", SP))
	io.write("\nActivity distribution indicator (AD) = ",string.format("%2.2f", AD))
	io.write("\nLength of arcs indicator (LA)        = ",string.format("%2.2f", LA))
	io.write("\nTopological float indicator (TF)     = ",string.format("%2.2f", TF))
	io.write('\n')
	delete_generator_object()
end

main_procedure_chapter4_part1()
